@@ -1,5 +1,5 @@
 /* join - join lines of two files on a common field
-   Copyright (C) 91, 1995-2001 Free Software Foundation, Inc.
+   Copyright (C) 91, 1995-2002 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "hard-locale.h"
 #include "linebuffer.h"
 #include "memcasecmp.h"
-#include "memcoll.h"
+#include "xmemcoll.h"
 #include "xstrtol.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
@@ -322,7 +322,8 @@ delseq (struct seq *seq)
 }
 
 /* Return <0 if the join field in LINE1 compares less than the one in LINE2;
-   >0 if it compares greater; 0 if it compares equal.  */
+   >0 if it compares greater; 0 if it compares equal.
+   Report an error and exit if the comparison fails.  */
 
 static int
 keycmp (struct line *line1, struct line *line2)
@@ -330,7 +331,7 @@ keycmp (struct line *line1, struct line *line2)
   /* Start of field to compare in each file.  */
   const unsigned char *beg1, *beg2;
 
-  int len1, len2;		/* Length of fields to compare.  */
+  size_t len1, len2;		/* Length of fields to compare.  */
   int diff;
 
   if (join_field_1 < line1->nfields)
@@ -373,14 +374,14 @@ keycmp (struct line *line1, struct line *line2)
     {
 #ifdef ENABLE_NLS
       if (hard_LC_COLLATE)
-	return memcoll ((char *) beg1, len1, (char *) beg2, len2);
+	return xmemcoll ((char *) beg1, len1, (char *) beg2, len2);
 #endif
       diff = memcmp (beg1, beg2, min (len1, len2));
     }
 
   if (diff)
     return diff;
-  return len1 - len2;
+  return len1 < len2 ? -1 : len1 != len2;
 }
 
 /* Print field N of LINE if it exists and is nonempty, otherwise
