@@ -1,5 +1,5 @@
 /* sort - sort lines of text (with all kinds of options).
-   Copyright (C) 88, 1991-2001 Free Software Foundation, Inc.
+   Copyright (C) 88, 1991-2002 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,10 +33,9 @@
 #include "error.h"
 #include "hard-locale.h"
 #include "human.h"
-#include "memcoll.h"
 #include "physmem.h"
 #include "stdio-safer.h"
-#include "xalloc.h"
+#include "xmemcoll.h"
 #include "xstrtol.h"
 
 #if HAVE_SYS_RESOURCE_H
@@ -286,23 +285,29 @@ usage (int status)
 Usage: %s [OPTION]... [FILE]...\n\
 "),
 	      program_name);
-      printf (_("\
+      fputs (_("\
 Write sorted concatenation of all FILE(s) to standard output.\n\
 \n\
 Ordering options:\n\
 \n\
+"), stdout);
+      fputs (_("\
+Mandatory arguments to long options are mandatory for short options too.\n\
+"), stdout);
+      fputs (_("\
   -b, --ignore-leading-blanks ignore leading blanks\n\
   -d, --dictionary-order      consider only blanks and alphanumeric characters\n\
   -f, --ignore-case           fold lower case to upper case characters\n\
+"), stdout);
+      fputs (_("\
   -g, --general-numeric-sort  compare according to general numerical value\n\
   -i, --ignore-nonprinting    consider only printable characters\n\
   -M, --month-sort            compare (unknown) < `JAN' < ... < `DEC'\n\
   -n, --numeric-sort          compare according to string numerical value\n\
   -r, --reverse               reverse the result of comparisons\n\
 \n\
-")
-	      );
-      printf (_("\
+"), stdout);
+      fputs (_("\
 Other options:\n\
 \n\
   -c, --check               check whether input is sorted; do not sort\n\
@@ -311,37 +316,43 @@ Other options:\n\
   -o, --output=FILE         write result to FILE instead of standard output\n\
   -s, --stable              stabilize sort by disabling last-resort comparison\n\
   -S, --buffer-size=SIZE    use SIZE for main memory buffer\n\
+"), stdout);
+      printf (_("\
   -t, --field-separator=SEP use SEP instead of non- to whitespace transition\n\
   -T, --temporary-directory=DIR  use DIR for temporaries, not $TMPDIR or %s\n\
                               multiple options specify multiple directories\n\
   -u, --unique              with -c: check for strict ordering\n\
                               otherwise: output only the first of an equal run\n\
+"), DEFAULT_TMPDIR);
+      fputs (_("\
   -z, --zero-terminated     end lines with 0 byte, not newline\n\
+"), stdout);
+      if (POSIX2_VERSION < 200112)
+	fputs (_("\
   +POS1 [-POS2]             start a key at POS1, end it before POS2 (origin 0)\n\
-                              Warning: this option is obsolescent\n\
-      --help       display this help and exit\n\
-      --version    output version information and exit\n\
+                              Warning: this option is obsolete\n\
+"), stdout);
+      fputs (HELP_OPTION_DESCRIPTION, stdout);
+      fputs (VERSION_OPTION_DESCRIPTION, stdout);
+      fputs (_("\
 \n\
-"),
-	      DEFAULT_TMPDIR);
-      printf (_("\
 POS is F[.C][OPTS], where F is the field number and C the character position\n\
-in the field, both counted from one with -k, from zero with the obsolescent\n\
-form.  OPTS is made up of one or more single-letter ordering options, which\n\
+in the field.  OPTS is one or more single-letter ordering options, which\n\
 override global ordering options for that key.  If no key is given, use the\n\
 entire line as the key.\n\
 \n\
 SIZE may be followed by the following multiplicative suffixes:\n\
-%% 1%% of memory, b 1, k 1024 (default), and so on for M, G, T, P, E, Z, Y.\n\
+"), stdout);
+      fputs (_("\
+% 1% of memory, b 1, K 1024 (default), and so on for M, G, T, P, E, Z, Y.\n\
 \n\
 With no FILE, or when FILE is -, read standard input.\n\
 \n\
 *** WARNING ***\n\
 The locale specified by the environment affects sort order.\n\
-Set LC_COLLATE=C to get the traditional sort order that uses\n\
+Set LC_ALL=C to get the traditional sort order that uses\n\
 native byte values.\n\
-")
-	      );
+"), stdout );
       puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
     }
   /* Don't use EXIT_FAILURE here in case it is defined to be 1.
@@ -405,7 +416,6 @@ static void
 die (char const *message, char const *file)
 {
   error (0, errno, "%s: %s", message, file);
-  cleanup ();
   exit (SORT_FAILURE);
 }
 
@@ -528,7 +538,7 @@ zaptemp (const char *name)
       }
 }
 
-#ifdef ENABLE_NLS
+#if defined ENABLE_NLS && HAVE_NL_LANGINFO
 
 static int
 struct_month_cmp (const void *m1, const void *m2)
@@ -537,7 +547,7 @@ struct_month_cmp (const void *m1, const void *m2)
 		 ((const struct month *) m2)->name);
 }
 
-#endif /* NLS */
+#endif
 
 /* Initialize the character class tables. */
 
@@ -592,9 +602,9 @@ specify_sort_size (char const *s)
 {
   uintmax_t n;
   char *suffix;
-  enum strtol_error e = xstrtoumax (s, &suffix, 10, &n, "EgGkmMPtTYZ");
+  enum strtol_error e = xstrtoumax (s, &suffix, 10, &n, "EgGkKmMPtTYZ");
 
-  /* The default unit is kB.  */
+  /* The default unit is KiB.  */
   if (e == LONGINT_OK && ISDIGIT (suffix[-1]))
     {
       if (n <= UINTMAX_MAX / 1024)
@@ -1390,14 +1400,14 @@ keycompare (const struct line *a, const struct line *b)
 		    }
 		}
 
-	      diff = memcoll (copy_a, new_len_a, copy_b, new_len_b);
+	      diff = xmemcoll (copy_a, new_len_a, copy_b, new_len_b);
 	    }
 	  else if (lena == 0)
 	    diff = - NONZERO (lenb);
 	  else if (lenb == 0)
 	    goto greater;
 	  else
-	    diff = memcoll (texta, lena, textb, lenb);
+	    diff = xmemcoll (texta, lena, textb, lenb);
 	}
 #endif
       else if (ignore)
@@ -1420,7 +1430,7 @@ keycompare (const struct line *a, const struct line *b)
 	      ++textb;							\
 	    }								\
 									\
-	  diff = (lima - texta) - (limb - textb);			\
+	  diff = (texta < lima) - (textb < limb);			\
     }									\
   while (0)
 
@@ -1521,7 +1531,7 @@ compare (register const struct line *a, register const struct line *b)
     diff = NONZERO (alen);
 #ifdef ENABLE_NLS
   else if (hard_LC_COLLATE)
-    diff = memcoll (a->text, alen, b->text, blen);
+    diff = xmemcoll (a->text, alen, b->text, blen);
 #endif
   else if (! (diff = memcmp (a->text, b->text, min (alen, blen))))
     diff = alen < blen ? -1 : alen != blen;
@@ -1638,27 +1648,27 @@ mergefps (char **files, register int nfiles,
   saved.text = NULL;
 
   /* Read initial lines from each input file. */
-  for (i = 0; i < nfiles; ++i)
+  for (i = 0; i < nfiles; )
     {
       fps[i] = xfopen (files[i], "r");
       initbuf (&buffer[i], sizeof (struct line),
 	       MAX (merge_buffer_size, sort_size / nfiles));
-      /* If a file is empty, eliminate it from future consideration. */
-      while (i < nfiles && !fillbuf (&buffer[i], fps[i], files[i]))
-	{
-	  xfclose (fps[i], files[i]);
-	  zaptemp (files[i]);
-	  --nfiles;
-	  for (j = i; j < nfiles; ++j)
-	    files[j] = files[j + 1];
-	}
-      if (i == nfiles)
-	free (buffer[i].buf);
-      else
+      if (fillbuf (&buffer[i], fps[i], files[i]))
 	{
 	  struct line const *linelim = buffer_linelim (&buffer[i]);
 	  cur[i] = linelim - 1;
 	  base[i] = linelim - buffer[i].nlines;
+	  i++;
+	}
+      else
+	{
+	  /* fps[i] is empty; eliminate it from future consideration.  */
+	  xfclose (fps[i], files[i]);
+	  zaptemp (files[i]);
+	  free (buffer[i].buf);
+	  --nfiles;
+	  for (j = i; j < nfiles; ++j)
+	    files[j] = files[j + 1];
 	}
     }
 
@@ -2173,6 +2183,8 @@ main (int argc, char **argv)
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
+  atexit (cleanup);
+
 #ifdef ENABLE_NLS
 
   hard_LC_COLLATE = hard_locale (LC_COLLATE);
@@ -2202,9 +2214,9 @@ main (int argc, char **argv)
   have_read_stdin = 0;
   inittables ();
 
-  /* Change the way xmalloc and xrealloc fail.  */
+  /* Change the way library functions fail.  */
   xalloc_exit_failure = SORT_FAILURE;
-  xalloc_fail_func = cleanup;
+  xmemcoll_exit_failure = SORT_FAILURE;
 
 #ifdef SA_NOCLDSTOP
   sigemptyset (&caught_signals);
@@ -2239,14 +2251,14 @@ main (int argc, char **argv)
   for (;;)
     {
       /* Parse an operand as a file after "--" was seen; or if
-         pedantic and a file was seen, unless -c was not seen and the
-         operand is "-o FILE" or "-oFILE".  POSIX 1003.1-200x d5
-         removes the exception for the -o options; when it becomes
-         official the code will need to be changed.  */
+         pedantic and a file was seen, unless the POSIX version
+         predates 1003.1-2001 and -c was not seen and the operand is
+         "-o FILE" or "-oFILE".  */
 
       if (c == -1
 	  || (posix_pedantic && nfiles != 0
-	      && ! (! checkonly
+	      && ! (POSIX2_VERSION < 200112
+		    && ! checkonly
 		    && optind != argc
 		    && argv[optind][0] == '-' && argv[optind][1] == 'o'
 		    && (argv[optind][2] || optind + 1 != argc)))
@@ -2262,14 +2274,11 @@ main (int argc, char **argv)
       else switch (c)
 	{
 	case 1:
-	  /* Treat +POS1 [-POS2] as a key if possible; but silently
-	     treat an operand as a file if it is not a valid +POS1.
-	     POSIX 1003.1-200x d5 does not allow support for +POS1, so
-	     when it becomes official this code will need to be
-	     changed.  */
 	  key = NULL;
-	  if (optarg[0] == '+')
+	  if (POSIX2_VERSION < 200112 && optarg[0] == '+')
 	    {
+	      /* Treat +POS1 [-POS2] as a key if possible; but silently
+		 treat an operand as a file if it is not a valid +POS1.  */
 	      key = new_key ();
 	      s = parse_field_count (optarg + 1, &key->sword, NULL);
 	      if (s && *s == '.')
@@ -2283,6 +2292,10 @@ main (int argc, char **argv)
 		}
 	      else
 		{
+		  if (! posix_pedantic)
+		    error (0, 0,
+			   _("warning: `sort %s' is obsolete; use `sort -k'"),
+			   optarg);
 		  if (optind != argc && argv[optind][0] == '-'
 		      && ISDIGIT (argv[optind][1]))
 		    {
@@ -2488,6 +2501,5 @@ main (int argc, char **argv)
   if (have_read_stdin && fclose (stdin) == EOF)
     die (_("close failed"), "-");
 
-  cleanup ();
   exit (EXIT_SUCCESS);
 }
