@@ -1,5 +1,5 @@
 /* uniq -- remove duplicate lines from a sorted file
-   Copyright (C) 86, 91, 1995-2001, Free Software Foundation, Inc.
+   Copyright (C) 86, 91, 1995-2002, Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -148,7 +148,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 "), stdout);
      fputs (_("\
   -D, --all-repeated[=delimit-method] print all duplicate lines\n\
-                        delimit-method={none(default),prepend,separate)}\n\
+                        delimit-method={none(default),prepend,separate}\n\
                         Delimiting is done with blank lines.\n\
   -f, --skip-fields=N   avoid comparing the first N fields\n\
   -i, --ignore-case     ignore differences in case when comparing\n\
@@ -158,7 +158,10 @@ Mandatory arguments to long options are mandatory for short options too.\n\
      fputs (_("\
   -w, --check-chars=N   compare no more than N characters in lines\n\
   -N                    same as -f N\n\
-  +N                    same as -s N (obsolescent; will be withdrawn)\n\
+"), stdout);
+     if (POSIX2_VERSION < 200112)
+       fputs (_("\
+  +N                    same as -s N (obsolete; will be withdrawn)\n\
 "), stdout);
      fputs (HELP_OPTION_DESCRIPTION, stdout);
      fputs (VERSION_OPTION_DESCRIPTION, stdout);
@@ -436,10 +439,17 @@ main (int argc, char **argv)
 	case 1:
 	  {
 	    unsigned long int size;
-	    if (optarg[0] == '+'
+	    if (POSIX2_VERSION < 200112
+		&& optarg[0] == '+'
 		&& xstrtoul (optarg, NULL, 10, &size, "") == LONGINT_OK
 		&& size <= SIZE_MAX)
-	      skip_chars = size;
+	      {
+		if (! posixly_correct)
+		  error (0, 0,
+			 _("warning: `uniq %s' is obsolete; use `uniq -s %s' instead"),
+			 optarg, optarg + 1);
+		skip_chars = size;
+	      }
 	    else if (nfiles == 2)
 	      {
 		error (0, 0, _("extra operand `%s'"), optarg);
